"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Segment = Segment;
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _reactNativeHapticFeedback = require("react-native-haptic-feedback");
var _reactNativeResponsiveScreen = require("react-native-responsive-screen");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultShadowStyle = {
  shadowColor: '#000',
  shadowOffset: {
    width: 1,
    height: 1
  },
  shadowOpacity: 0.025,
  shadowRadius: 1,
  elevation: 1
};
const DEFAULT_SPRING_CONFIG = {
  stiffness: 200,
  damping: 150,
  mass: 1,
  overshootClamping: false,
  restSpeedThreshold: 0.001,
  restDisplacementThreshold: 0.001
};
const SegmentedControl = _ref => {
  let {
    segments,
    currentIndex,
    onChange,
    haptics = false,
    badgeValues = [],
    isRTL = false,
    containerMargin = 0,
    activeTextStyle,
    inactiveTextStyle,
    segmentedControlWrapper,
    pressableWrapper,
    tileStyle,
    activeBadgeStyle,
    inactiveBadgeStyle,
    badgeTextStyle
  } = _ref;
  const width = +((segmentedControlWrapper === null || segmentedControlWrapper === void 0 ? void 0 : segmentedControlWrapper.width) ?? (0, _reactNativeResponsiveScreen.widthPercentageToDP)('100%') - containerMargin * 2);
  const translateValue = width / segments.length;
  const tabTranslateValue = (0, _reactNativeReanimated.useSharedValue)(0);
  const memoizedTabPressCallback = (0, _react.useCallback)(index => {
    haptics && (0, _reactNativeHapticFeedback.trigger)('impactLight', {
      enableVibrateFallback: true,
      ignoreAndroidSystemSettings: false
    });
    onChange(index);
  }, [onChange, haptics]);
  (0, _react.useEffect)(() => {
    // If phone is set to RTL, make sure the animation does the correct transition.
    const transitionMultiplier = isRTL ? -1 : 1;
    tabTranslateValue.value = (0, _reactNativeReanimated.withSpring)(currentIndex * (translateValue * transitionMultiplier), DEFAULT_SPRING_CONFIG);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [currentIndex]);
  const tabTranslateAnimatedStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      transform: [{
        translateX: tabTranslateValue.value
      }]
    };
  });
  const finalisedActiveTextStyle = {
    fontSize: 15,
    fontWeight: '600',
    textAlign: 'center',
    color: '#111827',
    ...activeTextStyle
  };
  const finalisedInActiveTextStyle = {
    fontSize: 15,
    textAlign: 'center',
    color: '#4b5563',
    ...inactiveTextStyle
  };
  const finalisedActiveBadgeStyle = {
    backgroundColor: '#FF3B30',
    marginLeft: 4,
    alignItems: 'center',
    justifyContent: 'center',
    ...activeBadgeStyle
  };
  const finalisedInActiveBadgeStyle = {
    backgroundColor: '#6b7280',
    marginLeft: 4,
    justifyContent: 'center',
    alignItems: 'center',
    ...inactiveBadgeStyle
  };
  const finalisedBadgeTextStyle = {
    fontSize: 11,
    fontWeight: '500',
    textAlign: 'center',
    color: '#FFFFFF',
    ...badgeTextStyle
  };
  const {
    margin,
    marginHorizontal,
    marginVertical,
    paddingVertical = 14
  } = tileStyle || {
    margin: 2,
    marginHorizontal: 2,
    marginVertical: 2,
    paddingVertical: 14
  };
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [styles.defaultSegmentedControlWrapper, segmentedControlWrapper]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [styles.movingSegmentStyle, defaultShadowStyle, tileStyle, _reactNative.StyleSheet.absoluteFill, {
      width: width / segments.length - +(margin || marginHorizontal || 2) * 2,
      marginHorizontal: marginHorizontal ?? margin,
      marginVertical: marginVertical ?? margin
    }, tabTranslateAnimatedStyles]
  }), segments.map((segment, index) => {
    const active = currentIndex === index ? finalisedActiveTextStyle : finalisedInActiveTextStyle;
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      activeOpacity: 0.5,
      onPress: () => memoizedTabPressCallback(index),
      key: index,
      style: [styles.touchableContainer, pressableWrapper, {
        paddingVertical
      }]
    }, typeof segment === 'string' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.textWrapper
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: active
    }, segment), badgeValues[index] && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.defaultBadgeContainerStyle, currentIndex === index ? finalisedActiveBadgeStyle : finalisedInActiveBadgeStyle]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: finalisedBadgeTextStyle
    }, badgeValues[index]))) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.cloneElement(segment, {
      active: currentIndex === index,
      badgeValue: badgeValues[index],
      finalisedBadgeTextStyle,
      badgeValueStatusStyle: currentIndex === index ? finalisedActiveBadgeStyle : finalisedInActiveBadgeStyle
    })));
  }));
};
function Segment(_ref2) {
  let {
    column,
    title,
    icon,
    leftIcon,
    rightIcon,
    position,
    space = 4,
    padding = 0,
    inactiveTitleStyle,
    activeTitleStyle,
    inactiveIconColor,
    activeIconColor,
    /* hidden: internal props */
    // @ts-ignore
    active,
    // @ts-ignore
    badgeValue,
    // @ts-ignore
    finalisedBadgeTextStyle,
    // @ts-ignore
    badgeValueStatusStyle
  } = _ref2;
  const flexDirection = column ? 'column' : 'row';
  const pos = !flexDirection ? {
    alignItems: position ?? 'center'
  } : {
    justifyContent: position ?? 'center'
  };
  const activeTitleDefaultStyle = {
    fontSize: 15,
    fontWeight: 'bold',
    textAlign: 'center',
    color: '#111827'
  };
  const inactiveTitleDefaultStyle = {
    fontSize: 15,
    fontWeight: 'bold',
    textAlign: 'center',
    color: '#4b5563'
  };
  const iconStatusColor = active ? activeIconColor ?? (activeTitleStyle === null || activeTitleStyle === void 0 ? void 0 : activeTitleStyle.color) ?? activeTitleDefaultStyle.color : inactiveIconColor ?? (inactiveTitleStyle === null || inactiveTitleStyle === void 0 ? void 0 : inactiveTitleStyle.color) ?? inactiveTitleDefaultStyle.color;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.segmentWrapper, {
      padding,
      flexDirection,
      ...pos
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color: iconStatusColor
    }
  }, icon ?? leftIcon), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      width: space
    }
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: active ? [activeTitleDefaultStyle, activeTitleStyle] : [inactiveTitleDefaultStyle, inactiveTitleStyle]
  }, title), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      width: space
    }
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color: iconStatusColor
    }
  }, rightIcon), badgeValue != null && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.defaultBadgeContainerStyle, badgeValueStatusStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: finalisedBadgeTextStyle
  }, badgeValue)));
}
const styles = _reactNative.StyleSheet.create({
  defaultSegmentedControlWrapper: {
    position: 'relative',
    display: 'flex',
    flexDirection: 'row',
    alignItems: 'center',
    borderRadius: 9,
    backgroundColor: '#f3f4f6'
  },
  touchableContainer: {
    flex: 1,
    elevation: 9,
    paddingVertical: 14
  },
  segmentWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center'
  },
  textWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center'
  },
  movingSegmentStyle: {
    top: 0,
    marginVertical: 2,
    marginHorizontal: 2,
    borderRadius: 7,
    backgroundColor: '#FFFFFF'
  },
  // Badge Styles
  defaultBadgeContainerStyle: {
    alignItems: 'center',
    justifyContent: 'center',
    height: 16,
    width: 16,
    borderRadius: 9999,
    alignContent: 'flex-end'
  }
});
var _default = SegmentedControl;
exports.default = _default;
//# sourceMappingURL=index.js.map