import React, { useCallback, useEffect } from 'react';
import { TouchableOpacity, StyleSheet, Text, View } from 'react-native';
import Animated, { useAnimatedStyle, useSharedValue, withSpring } from 'react-native-reanimated';
import { trigger } from 'react-native-haptic-feedback';
import { widthPercentageToDP } from 'react-native-responsive-screen';
const defaultShadowStyle = {
  shadowColor: '#000',
  shadowOffset: {
    width: 1,
    height: 1
  },
  shadowOpacity: 0.025,
  shadowRadius: 1,
  elevation: 1
};
const DEFAULT_SPRING_CONFIG = {
  stiffness: 200,
  damping: 150,
  mass: 1,
  overshootClamping: false,
  restSpeedThreshold: 0.001,
  restDisplacementThreshold: 0.001
};
const SegmentedControl = _ref => {
  let {
    segments,
    currentIndex,
    onChange,
    haptics = false,
    badgeValues = [],
    isRTL = false,
    containerMargin = 0,
    activeTextStyle,
    inactiveTextStyle,
    segmentedControlWrapper,
    pressableWrapper,
    tileStyle,
    activeBadgeStyle,
    inactiveBadgeStyle,
    badgeTextStyle
  } = _ref;
  const width = +((segmentedControlWrapper === null || segmentedControlWrapper === void 0 ? void 0 : segmentedControlWrapper.width) ?? widthPercentageToDP('100%') - containerMargin * 2);
  const translateValue = width / segments.length;
  const tabTranslateValue = useSharedValue(0);
  const memoizedTabPressCallback = useCallback(index => {
    haptics && trigger('impactLight', {
      enableVibrateFallback: true,
      ignoreAndroidSystemSettings: false
    });
    onChange(index);
  }, [onChange, haptics]);
  useEffect(() => {
    // If phone is set to RTL, make sure the animation does the correct transition.
    const transitionMultiplier = isRTL ? -1 : 1;
    tabTranslateValue.value = withSpring(currentIndex * (translateValue * transitionMultiplier), DEFAULT_SPRING_CONFIG);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [currentIndex]);
  const tabTranslateAnimatedStyles = useAnimatedStyle(() => {
    return {
      transform: [{
        translateX: tabTranslateValue.value
      }]
    };
  });
  const finalisedActiveTextStyle = {
    fontSize: 15,
    fontWeight: '600',
    textAlign: 'center',
    color: '#111827',
    ...activeTextStyle
  };
  const finalisedInActiveTextStyle = {
    fontSize: 15,
    textAlign: 'center',
    color: '#4b5563',
    ...inactiveTextStyle
  };
  const finalisedActiveBadgeStyle = {
    backgroundColor: '#FF3B30',
    marginLeft: 4,
    alignItems: 'center',
    justifyContent: 'center',
    ...activeBadgeStyle
  };
  const finalisedInActiveBadgeStyle = {
    backgroundColor: '#6b7280',
    marginLeft: 4,
    justifyContent: 'center',
    alignItems: 'center',
    ...inactiveBadgeStyle
  };
  const finalisedBadgeTextStyle = {
    fontSize: 11,
    fontWeight: '500',
    textAlign: 'center',
    color: '#FFFFFF',
    ...badgeTextStyle
  };
  const {
    margin,
    marginHorizontal,
    marginVertical,
    paddingVertical = 14
  } = tileStyle || {
    margin: 2,
    marginHorizontal: 2,
    marginVertical: 2,
    paddingVertical: 14
  };
  return /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.defaultSegmentedControlWrapper, segmentedControlWrapper]
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.movingSegmentStyle, defaultShadowStyle, tileStyle, StyleSheet.absoluteFill, {
      width: width / segments.length - +(margin || marginHorizontal || 2) * 2,
      marginHorizontal: marginHorizontal ?? margin,
      marginVertical: marginVertical ?? margin
    }, tabTranslateAnimatedStyles]
  }), segments.map((segment, index) => {
    const active = currentIndex === index ? finalisedActiveTextStyle : finalisedInActiveTextStyle;
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      activeOpacity: 0.5,
      onPress: () => memoizedTabPressCallback(index),
      key: index,
      style: [styles.touchableContainer, pressableWrapper, {
        paddingVertical
      }]
    }, typeof segment === 'string' ? /*#__PURE__*/React.createElement(View, {
      style: styles.textWrapper
    }, /*#__PURE__*/React.createElement(Text, {
      style: active
    }, segment), badgeValues[index] && /*#__PURE__*/React.createElement(View, {
      style: [styles.defaultBadgeContainerStyle, currentIndex === index ? finalisedActiveBadgeStyle : finalisedInActiveBadgeStyle]
    }, /*#__PURE__*/React.createElement(Text, {
      style: finalisedBadgeTextStyle
    }, badgeValues[index]))) : /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.cloneElement(segment, {
      active: currentIndex === index,
      badgeValue: badgeValues[index],
      finalisedBadgeTextStyle,
      badgeValueStatusStyle: currentIndex === index ? finalisedActiveBadgeStyle : finalisedInActiveBadgeStyle
    })));
  }));
};
export function Segment(_ref2) {
  let {
    column,
    title,
    icon,
    leftIcon,
    rightIcon,
    position,
    space = 4,
    padding = 0,
    inactiveTitleStyle,
    activeTitleStyle,
    inactiveIconColor,
    activeIconColor,
    /* hidden: internal props */
    // @ts-ignore
    active,
    // @ts-ignore
    badgeValue,
    // @ts-ignore
    finalisedBadgeTextStyle,
    // @ts-ignore
    badgeValueStatusStyle
  } = _ref2;
  const flexDirection = column ? 'column' : 'row';
  const pos = !flexDirection ? {
    alignItems: position ?? 'center'
  } : {
    justifyContent: position ?? 'center'
  };
  const activeTitleDefaultStyle = {
    fontSize: 15,
    fontWeight: 'bold',
    textAlign: 'center',
    color: '#111827'
  };
  const inactiveTitleDefaultStyle = {
    fontSize: 15,
    fontWeight: 'bold',
    textAlign: 'center',
    color: '#4b5563'
  };
  const iconStatusColor = active ? activeIconColor ?? (activeTitleStyle === null || activeTitleStyle === void 0 ? void 0 : activeTitleStyle.color) ?? activeTitleDefaultStyle.color : inactiveIconColor ?? (inactiveTitleStyle === null || inactiveTitleStyle === void 0 ? void 0 : inactiveTitleStyle.color) ?? inactiveTitleDefaultStyle.color;
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.segmentWrapper, {
      padding,
      flexDirection,
      ...pos
    }]
  }, /*#__PURE__*/React.createElement(Text, {
    style: {
      color: iconStatusColor
    }
  }, icon ?? leftIcon), /*#__PURE__*/React.createElement(View, {
    style: {
      width: space
    }
  }), /*#__PURE__*/React.createElement(Text, {
    style: active ? [activeTitleDefaultStyle, activeTitleStyle] : [inactiveTitleDefaultStyle, inactiveTitleStyle]
  }, title), /*#__PURE__*/React.createElement(View, {
    style: {
      width: space
    }
  }), /*#__PURE__*/React.createElement(Text, {
    style: {
      color: iconStatusColor
    }
  }, rightIcon), badgeValue != null && /*#__PURE__*/React.createElement(View, {
    style: [styles.defaultBadgeContainerStyle, badgeValueStatusStyle]
  }, /*#__PURE__*/React.createElement(Text, {
    style: finalisedBadgeTextStyle
  }, badgeValue)));
}
const styles = StyleSheet.create({
  defaultSegmentedControlWrapper: {
    position: 'relative',
    display: 'flex',
    flexDirection: 'row',
    alignItems: 'center',
    borderRadius: 9,
    backgroundColor: '#f3f4f6'
  },
  touchableContainer: {
    flex: 1,
    elevation: 9,
    paddingVertical: 14
  },
  segmentWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center'
  },
  textWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center'
  },
  movingSegmentStyle: {
    top: 0,
    marginVertical: 2,
    marginHorizontal: 2,
    borderRadius: 7,
    backgroundColor: '#FFFFFF'
  },
  // Badge Styles
  defaultBadgeContainerStyle: {
    alignItems: 'center',
    justifyContent: 'center',
    height: 16,
    width: 16,
    borderRadius: 9999,
    alignContent: 'flex-end'
  }
});
export default SegmentedControl;
//# sourceMappingURL=index.js.map